@@ -67,7 +67,6 @@ void _al_shutdown_native_dialog_addon(void)
    wm_size_cond = NULL;
 }
 
-
 static bool select_folder(ALLEGRO_DISPLAY_WIN *win_display,
    ALLEGRO_NATIVE_DIALOG *fd)
 {
@@ -76,7 +75,7 @@ static bool select_folder(ALLEGRO_DISPLAY_WIN *win_display,
    char buf[MAX_PATH] = "";
    char dbuf[MAX_PATH] = "";
 
-   folderinfo.hwndOwner = win_display->window;
+   folderinfo.hwndOwner = win_display ? win_display->window : NULL;
    folderinfo.pidlRoot = NULL;
    folderinfo.pszDisplayName = dbuf;
    folderinfo.lpszTitle = al_cstr(fd->title);
@@ -177,7 +176,7 @@ bool _al_show_native_file_dialog(ALLEGRO_DISPLAY *display,
    /* Selecting a file. */
    memset(&ofn, 0, sizeof(OPENFILENAME));
    ofn.lStructSize = sizeof(OPENFILENAME);
-   ofn.hwndOwner = (win_display) ? win_display->window : NULL;
+   ofn.hwndOwner = win_display ? win_display->window : NULL;
 
    /* Create filter string. */
    if (fd->fc_patterns) {
@@ -703,9 +702,14 @@ static bool menu_callback(ALLEGRO_DISPLAY *display, UINT msg, WPARAM wParam, LPA
    if (msg == WM_COMMAND && lParam == 0) {
       const int id = LOWORD(wParam);
       _AL_MENU_ID *menu_id = _al_find_parent_menu_by_id(display, id);
-      if (menu_id && (al_get_menu_item_flags(menu_id->menu, id) & ALLEGRO_MENU_ITEM_CHECKBOX)) {
-         /* Toggle the checkbox, since Windows doesn't do that automatically. */
-         al_toggle_menu_item_flags(menu_id->menu, id, ALLEGRO_MENU_ITEM_CHECKED);
+      if (menu_id) {
+         int index;
+         if (_al_find_menu_item_unique(menu_id->menu, id, NULL, &index)) {
+            if (al_get_menu_item_flags(menu_id->menu, -index) & ALLEGRO_MENU_ITEM_CHECKBOX) {
+               /* Toggle the checkbox, since Windows doesn't do that automatically. */
+               al_toggle_menu_item_flags(menu_id->menu, -index, ALLEGRO_MENU_ITEM_CHECKED);
+            }
+         }
       }
       _al_emit_menu_event(display, id);
       return true;
