@@ -20,7 +20,7 @@ typedef struct ALLEGRO_SYSTEM_INTERFACE ALLEGRO_SYSTEM_INTERFACE;
 
 struct ALLEGRO_SYSTEM_INTERFACE
 {
-   int id;
+   ALLEGRO_SYSTEM_ID id;
    ALLEGRO_SYSTEM *(*initialize)(int flags);
    ALLEGRO_DISPLAY_INTERFACE *(*get_display_driver)(void);
    ALLEGRO_KEYBOARD_DRIVER *(*get_keyboard_driver)(void);
@@ -33,6 +33,7 @@ struct ALLEGRO_SYSTEM_INTERFACE
    void (*shutdown_system)(void);
    int (*get_num_video_adapters)(void);
    bool (*get_monitor_info)(int adapter, ALLEGRO_MONITOR_INFO *info);
+   int (*get_monitor_dpi)(int adapter);
    ALLEGRO_MOUSE_CURSOR *(*create_mouse_cursor)(ALLEGRO_BITMAP *bmp, int x_focus, int y_focus);
    void (*destroy_mouse_cursor)(ALLEGRO_MOUSE_CURSOR *cursor);
    bool (*get_cursor_position)(int *ret_x, int *ret_y);
