@@ -10,6 +10,9 @@ typedef struct
 {
    ALLEGRO_SYSTEM system;
    ALLEGRO_MUTEX *mutex;
+   #ifdef __EMSCRIPTEN__
+      double timer_time;
+   #endif
 } ALLEGRO_SYSTEM_SDL;
 
 typedef struct ALLEGRO_DISPLAY_SDL
@@ -18,8 +21,6 @@ typedef struct ALLEGRO_DISPLAY_SDL
 
    int x, y;
    SDL_Window *window;
-   char *title;
-   SDL_Renderer *renderer;
    SDL_GLContext context;
 } ALLEGRO_DISPLAY_SDL;
 
@@ -27,11 +28,13 @@ ALLEGRO_SYSTEM_INTERFACE *_al_sdl_system_driver(void);
 ALLEGRO_DISPLAY_INTERFACE *_al_sdl_display_driver(void);
 ALLEGRO_KEYBOARD_DRIVER *_al_sdl_keyboard_driver(void);
 ALLEGRO_MOUSE_DRIVER *_al_sdl_mouse_driver(void);
+ALLEGRO_TOUCH_INPUT_DRIVER *_al_sdl_touch_input_driver(void);
 ALLEGRO_JOYSTICK_DRIVER *_al_sdl_joystick_driver(void);
 ALLEGRO_BITMAP_INTERFACE *_al_sdl_bitmap_driver(void);
 
 void _al_sdl_keyboard_event(SDL_Event *e);
 void _al_sdl_mouse_event(SDL_Event *e);
+void _al_sdl_touch_input_event(SDL_Event *e);
 void _al_sdl_display_event(SDL_Event *e);
 void _al_sdl_joystick_event(SDL_Event *e);
 
@@ -39,6 +42,7 @@ int _al_sdl_get_allegro_pixel_format(int sdl_format);
 int _al_sdl_get_sdl_pixel_format(int allegro_format);
 
 ALLEGRO_DISPLAY *_al_sdl_find_display(uint32_t window_id);
+float _al_sdl_get_display_pixel_ratio(ALLEGRO_DISPLAY *display);
 
 void _al_sdl_event_hack(void);
 
