@@ -104,7 +104,7 @@ void _al_ogl_reset_fbo_info(ALLEGRO_FBO_INFO *info)
 }
 
 
-#if !defined ALLEGRO_RASPBERRYPI && (!defined ALLEGRO_ANDROID || defined ALLEGRO_CFG_OPENGLES3) && !defined ALLEGRO_CFG_OPENGLES
+#if (!defined ALLEGRO_CFG_OPENGLES) || defined ALLEGRO_CFG_OPENGLES3
 static void check_gl_error(void)
 {
    GLint e = glGetError();
@@ -175,7 +175,9 @@ static void attach_depth_buffer(ALLEGRO_FBO_INFO *info)
       int w = al_get_bitmap_width(info->owner);
       int h = al_get_bitmap_height(info->owner);
 
+#if !defined ALLEGRO_CFG_OPENGLES || defined ALLEGRO_CFG_OPENGLES3
       if (bits == 24) gldepth = GL_DEPTH_COMPONENT24;
+#endif
    
       glGenRenderbuffersEXT(1, &rb);
       glBindRenderbufferEXT(GL_RENDERBUFFER_EXT, rb);
@@ -192,7 +194,7 @@ static void attach_depth_buffer(ALLEGRO_FBO_INFO *info)
 
       if (samples == 0 || !extension_supported)
          glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, gldepth, w, h);
-#if !defined ALLEGRO_ANDROID || defined ALLEGRO_CFG_OPENGLES3
+#if !defined ALLEGRO_CFG_OPENGLES || defined ALLEGRO_CFG_OPENGLES3
       else
          glRenderbufferStorageMultisampleEXT(GL_RENDERBUFFER_EXT,
             samples, gldepth, w, h);
@@ -230,7 +232,7 @@ static void attach_depth_buffer(ALLEGRO_FBO_INFO *info)
 
 static void attach_multisample_buffer(ALLEGRO_FBO_INFO *info)
 {
-#if !defined ALLEGRO_RASPBERRYPI && (!defined ALLEGRO_ANDROID || defined ALLEGRO_CFG_OPENGLES3)
+#if !defined ALLEGRO_CFG_OPENGLES || defined ALLEGRO_CFG_OPENGLES3
    ALLEGRO_BITMAP *b = info->owner;
    int samples = al_get_bitmap_samples(b);
 
@@ -619,7 +621,7 @@ static void use_fbo_for_bitmap(ALLEGRO_DISPLAY *display,
             glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
                GL_TEXTURE_2D, ogl_bitmap->texture, 0);
          }
-#if !defined ALLEGRO_IPHONE && (!defined ALLEGRO_ANDROID || defined ALLEGRO_CFG_OPENGLES3)
+#if ((!defined ALLEGRO_CFG_OPENGLES || defined ALLEGRO_CFG_OPENGLES3) && !defined ALLEGRO_IPHONE)
          else {
             glFramebufferTexture2DMultisampleEXT(GL_FRAMEBUFFER,
                GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, ogl_bitmap->texture, 
