@@ -65,7 +65,39 @@ void _al_thread_create(_AL_THREAD *thread, void (*proc)(_AL_THREAD*, void*), voi
       status = pthread_create(&thread->thread, NULL, thread_proc_trampoline, thread);
       ASSERT(status == 0);
       if (status != 0)
-	 abort();
+         abort();
+   }
+}
+
+
+void _al_thread_create_with_stacksize(_AL_THREAD* thread, void (*proc)(_AL_THREAD*, void*), void *arg, size_t stacksize) 
+{
+   ASSERT(stacksize >= PTHREAD_STACK_MIN);
+   ASSERT(thread);
+   ASSERT(proc);
+   {
+      int status;
+
+      pthread_mutex_init(&thread->mutex, NULL);
+
+      thread->should_stop = false;
+      thread->proc = proc;
+      thread->arg = arg;
+
+      pthread_attr_t thread_attr;
+      int result = 0;
+      result = pthread_attr_init(&thread_attr);
+      ASSERT(result == 0);
+		
+      // On some systems, pthread_attr_setstacksize() can fail
+      // if stacksize is not a multiple of the system page size.
+      result = pthread_attr_setstacksize(&thread_attr, stacksize);
+      ASSERT(result == 0);
+		
+      status = pthread_create(&thread->thread, &thread_attr, thread_proc_trampoline, thread);
+      ASSERT(status == 0);
+      if (status != 0)
+         abort();
    }
 }
 
