@@ -1901,9 +1901,9 @@ void _al_d3d_set_blender(ALLEGRO_DISPLAY_D3D *d3d_display)
 
    blender_changed = false;
 
-   al_get_separate_blender(&op, &src, &dst,
+   al_get_separate_bitmap_blender(&op, &src, &dst,
       &alpha_op, &alpha_src, &alpha_dst);
-   color = al_get_blend_color();
+   color = al_get_bitmap_blend_color();
    al_unmap_rgba(color, &r, &g, &b, &a);
 
    if (d3d_display->blender_state_op != op) {
